==> gs2-java-sdk-3.1.8-sources.jar: io/gs2/account/result/AuthenticationResult.java <==
/*
 * Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package io.gs2.account.result;

import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.StreamSupport;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.JsonNode;
import io.gs2.core.model.*;
import io.gs2.account.model.*;
import io.gs2.account.model.Account;

@SuppressWarnings("serial")
@JsonIgnoreProperties(ignoreUnknown=true)
public class AuthenticationResult implements IResult, Serializable {
    private Account item;
    private String body;
    private String signature;

	public Account getItem() {
		return item;
	}

	public void setItem(Account item) {
		this.item = item;
	}

	public AuthenticationResult withItem(Account item) {
		this.item = item;
		return this;
	}

	public String getBody() {
		return body;
	}

	public void setBody(String body) {
		this.body = body;
	}

	public AuthenticationResult withBody(String body) {
		this.body = body;
		return this;
	}

	public String getSignature() {
		return signature;
	}

	public void setSignature(String signature) {
		this.signature = signature;
	}

	public AuthenticationResult withSignature(String signature) {
		this.signature = signature;
		return this;
	}

    public static AuthenticationResult fromJson(JsonNode data) {
        if (data == null) {
            return null;
        }
        return new AuthenticationResult()
            .withItem(data.get("item") == null || data.get("item").isNull() ? null : Account.fromJson(data.get("item")))
            .withBody(data.get("body") == null || data.get("body").isNull() ? null : data.get("body").asText())
            .withSignature(data.get("signature") == null || data.get("signature").isNull() ? null : data.get("signature").asText());
    }

    public JsonNode toJson() {
        return new ObjectMapper().valueToTree(
            new HashMap<String, Object>() {{
                put("item", getItem() != null ? getItem().toJson() : null);
                put("body", getBody());
                put("signature", getSignature());
            }}
        );
    }
}

==> gs2-java-sdk-3.1.201-sources.jar: io/gs2/account/result/AuthenticationResult.java <==
/*
 * Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package io.gs2.account.result;

import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.StreamSupport;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.JsonNode;
import io.gs2.core.model.*;
import io.gs2.account.model.*;
import io.gs2.account.model.BanStatus;
import io.gs2.account.model.Account;

@SuppressWarnings("serial")
@JsonIgnoreProperties(ignoreUnknown=true)
public class AuthenticationResult implements IResult, Serializable {
    private Account item;
    private List<BanStatus> banStatuses;
    private String body;
    private String signature;

	public Account getItem() {
		return item;
	}

	public void setItem(Account item) {
		this.item = item;
	}

	public AuthenticationResult withItem(Account item) {
		this.item = item;
		return this;
	}

	public List<BanStatus> getBanStatuses() {
		return banStatuses;
	}

	public void setBanStatuses(List<BanStatus> banStatuses) {
		this.banStatuses = banStatuses;
	}

	public AuthenticationResult withBanStatuses(List<BanStatus> banStatuses) {
		this.banStatuses = banStatuses;
		return this;
	}

	public String getBody() {
		return body;
	}

	public void setBody(String body) {
		this.body = body;
	}

	public AuthenticationResult withBody(String body) {
		this.body = body;
		return this;
	}

	public String getSignature() {
		return signature;
	}

	public void setSignature(String signature) {
		this.signature = signature;
	}

	public AuthenticationResult withSignature(String signature) {
		this.signature = signature;
		return this;
	}

    public static AuthenticationResult fromJson(JsonNode data) {
        if (data == null) {
            return null;
        }
        return new AuthenticationResult()
            .withItem(data.get("item") == null || data.get("item").isNull() ? null : Account.fromJson(data.get("item")))
            .withBanStatuses(data.get("banStatuses") == null || data.get("banStatuses").isNull() ? new ArrayList<BanStatus>() :
                StreamSupport.stream(Spliterators.spliteratorUnknownSize(data.get("banStatuses").elements(), Spliterator.NONNULL), false).map(item -> {
                    //noinspection Convert2MethodRef
                    return BanStatus.fromJson(item);
                }
            ).collect(Collectors.toList()))
            .withBody(data.get("body") == null || data.get("body").isNull() ? null : data.get("body").asText())
            .withSignature(data.get("signature") == null || data.get("signature").isNull() ? null : data.get("signature").asText());
    }

    public JsonNode toJson() {
        return new ObjectMapper().valueToTree(
            new HashMap<String, Object>() {{
                put("item", getItem() != null ? getItem().toJson() : null);
                put("banStatuses", getBanStatuses() == null ? new ArrayList<BanStatus>() :
                    getBanStatuses().stream().map(item -> {
                        //noinspection Convert2MethodRef
                        return item.toJson();
                    }
                ).collect(Collectors.toList()));
                put("body", getBody());
                put("signature", getSignature());
            }}
        );
    }
}
